Typed options for Slack edit_message/4.
Summary
Functions
Builds edit options from a struct, keyword list, or map.
Builds Slack API payload options for message edits.
Returns the Zoi schema for edit options.
Extracts transport options for Slack edit calls.
Types
Functions
Builds edit options from a struct, keyword list, or map.
Builds Slack API payload options for message edits.
Returns the Zoi schema for edit options.
Extracts transport options for Slack edit calls.