Jido.Chat.Slack.FetchOptions (Jido Chat Slack v1.0.0)

Copy Markdown View Source

Typed options for Slack history fetch operations.

Summary

Functions

Builds fetch options from a struct, keyword list, or map.

Returns the Zoi schema for fetch options.

Extracts transport options for Slack history calls.

Types

t()

@type t() :: %Jido.Chat.Slack.FetchOptions{
  cursor: nil | nil | binary(),
  direction: :forward | :backward,
  inclusive: nil | nil | boolean(),
  limit: integer(),
  req: nil | nil | any(),
  thread_ts: nil | nil | any(),
  token: nil | nil | binary(),
  transport: any()
}

Functions

new(opts)

@spec new(t() | keyword() | map()) :: t()

Builds fetch options from a struct, keyword list, or map.

schema()

Returns the Zoi schema for fetch options.

transport_opts(opts)

@spec transport_opts(t()) :: keyword()

Extracts transport options for Slack history calls.